==> openshift-model-hive-5.12.3-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class SelectorSyncSetBuilder extends io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluentImpl<io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetBuilder>{
  public SelectorSyncSetBuilder() {
    this(false);
  }
  public SelectorSyncSetBuilder(java.lang.Boolean validationEnabled) {
    this(new SelectorSyncSet(), validationEnabled);
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new SelectorSyncSet(), validationEnabled);
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet instance) {
    this(instance,false);
  }
  public SelectorSyncSetBuilder(io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.SelectorSyncSetFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.SelectorSyncSet build() {
    SelectorSyncSet buildable = new SelectorSyncSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    SelectorSyncSetBuilder that = (SelectorSyncSetBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.5.1-sources.jar: io/fabric8/openshift/api/model/hive/v1/SelectorSyncSetBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class SelectorSyncSetBuilder extends SelectorSyncSetFluentImpl<SelectorSyncSetBuilder> implements VisitableBuilder<SelectorSyncSet,SelectorSyncSetBuilder>{
  public SelectorSyncSetBuilder() {
    this(false);
  }
  public SelectorSyncSetBuilder(Boolean validationEnabled) {
    this(new SelectorSyncSet(), validationEnabled);
  }
  public SelectorSyncSetBuilder(SelectorSyncSetFluent<?> fluent) {
    this(fluent, false);
  }
  public SelectorSyncSetBuilder(SelectorSyncSetFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new SelectorSyncSet(), validationEnabled);
  }
  public SelectorSyncSetBuilder(SelectorSyncSetFluent<?> fluent,SelectorSyncSet instance) {
    this(fluent, instance, false);
  }
  public SelectorSyncSetBuilder(SelectorSyncSetFluent<?> fluent,SelectorSyncSet instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public SelectorSyncSetBuilder(SelectorSyncSet instance) {
    this(instance,false);
  }
  public SelectorSyncSetBuilder(SelectorSyncSet instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  SelectorSyncSetFluent<?> fluent;
  Boolean validationEnabled;
  public SelectorSyncSet build() {
    SelectorSyncSet buildable = new SelectorSyncSet(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
